Struct amazon_sp_services::models::reservation::Reservation
source · [−]pub struct Reservation {
pub reservation_id: Option<String>,
pub _type: Type,
pub availability: Box<AvailabilityRecord>,
}Expand description
Reservation : Reservation object reduces the capacity of a resource.
Fields
reservation_id: Option<String>Unique identifier for a reservation. If present, it is treated as an update reservation request and will update the corresponding reservation. Otherwise, it is treated as a new create reservation request.
_type: TypeType of reservation.
availability: Box<AvailabilityRecord>Implementations
sourceimpl Reservation
impl Reservation
sourcepub fn new(_type: Type, availability: AvailabilityRecord) -> Reservation
pub fn new(_type: Type, availability: AvailabilityRecord) -> Reservation
Reservation object reduces the capacity of a resource.